@@ -12,7 +12,7 @@ if os.path.exists(project_root_file):
     if config['Project_Root'].getboolean('use_absolute_path'):
         project_root = config['Project_Root']['absolute_path']
     else:
-        project_root = Path(os.path.abspath(__name__))
+        project_root = Path(os.path.abspath(__name__)).parent
         for i in range(int(config['Project_Root']['folder_level'])):
             project_root = project_root.parent
         project_root = str(project_root)
